<?php

namespace Ipqualityscore\Ipqualityscore\Events\Observer;

use Magento\Framework\Event\ObserverInterface;
use Psr\Log\LoggerInterface;

class NewOrder implements ObserverInterface
{
    protected $logger;
    protected $scopeConfig;

    public function __construct(LoggerInterface $logger, \Magento\Framework\App\RequestInterface $request, \Magento\Framework\View\Page\Config $pageConfig,  \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig)
    {
        $this->logger = $logger;
        $this->_request = $request;
        $this->_page = $pageConfig;
        $this->scopeConfig = $scopeConfig;
    }

    public function execute(\Magento\Framework\Event\Observer $observer)
    {
        try {
            require_once dirname(__FILE__) . '/../../Integration.php';
            $isAuthed = $this->scopeConfig->getValue('ipqualityscore/general/auth_token', \Magento\Store\Model\ScopeInterface::SCOPE_STORE);
            if ($isAuthed) {
                $order = $observer->getEvent()->getOrder();
                $orderId = $order->getId();
                $customerId = $order->getCustomerId();
                $this->logger->info("Customer Id: " . $customerId);
                $email = $order->getCustomerEmail();
                $firstname = $order->getCustomerFirstName();
                $lastname = $order->getCustomerLastname();
                $shipping = $order->getBillingAddress()->getData();
                $billing = $order->getBillingAddress()->getData();

                $this->logger->info("Shipping: " . json_encode($shipping));
                $this->logger->info("Billing: " . json_encode($billing));


                $blockAll = $this->scopeConfig->getValue('ipqualityscore/general/block_all', \Magento\Store\Model\ScopeInterface::SCOPE_STORE);
                $blockVpn = $this->scopeConfig->getValue('ipqualityscore/general/block_vpn', \Magento\Store\Model\ScopeInterface::SCOPE_STORE);
                $blockTor = $this->scopeConfig->getValue('ipqualityscore/general/block_tor', \Magento\Store\Model\ScopeInterface::SCOPE_STORE);
                $strictness = $this->scopeConfig->getValue('ipqualityscore/general/strictness', \Magento\Store\Model\ScopeInterface::SCOPE_STORE);
                $allowPublic = $this->scopeConfig->getValue('ipqualityscore/general/allow_public', \Magento\Store\Model\ScopeInterface::SCOPE_STORE) ? true : false;
                $allowCrawlers = $this->scopeConfig->getValue('ipqualityscore/general/allow_crawlers', \Magento\Store\Model\ScopeInterface::SCOPE_STORE) ? true : false;
                $blockScore = $this->scopeConfig->getValue('ipqualityscore/general/block_score', \Magento\Store\Model\ScopeInterface::SCOPE_STORE);
                $redirect = $this->scopeConfig->getValue('ipqualityscore/general/redirect', \Magento\Store\Model\ScopeInterface::SCOPE_STORE);
                $allowAdminProxyLogin =  $this->scopeConfig->getValue('ipqualityscore/general/allow_admin_login', \Magento\Store\Model\ScopeInterface::SCOPE_STORE);
                $client = new \IpqualityScore\Integration($isAuthed, 'magentov2');
                $user = [
                    'billing_firstname' => $billing['firstname'],
                    'billing_lastname' => $billing['lastname'],
                    'billing_company' => $billing['company'],
                    'billing_country' => $billing['country_id'],
                    'billing_address' => $billing['street'],
                    'billing_city' => $billing['city'],
                    'billing_state' => $billing['region'],
                    'billing_postcalcode' => $billing['postcode'],
                    'billing_phone' => $billing['telephone'],
                    'billing_email' => $billing['email'],
                    'shipping_firstname' => $shipping['firstname'],
                    'shipping_lastname' => $shipping['lastname'],
                    'shipping_company' => $shipping['company'],
                    'shipping_country' => $shipping['country_id'],
                    'shipping_address' => $shipping['street'],
                    'shipping_city' => $shipping['city'],
                    'shipping_state' => $shipping['region'],
                    'shipping_postcalcode' => $shipping['postcode'],
                    'shipping_phone' => $shipping['telephone'],
                    'shipping_email' => $shipping['email']
                ];


                $response = $client->validateProxy($strictness, $allowPublic, false, true, $user);
                $response->proxy = $response->proxy ? 1 : 0;
                $response->vpn = $response->vpn ? 1 : 0;
                $response->tor = $response->tor ? 1 : 0;
                $response->recent_abuse = $response->recent_abuse ? 1 : 0;
                $response->bot_status = $response->bot_status ? 1 : 0;
                $response->mobile = $response->mobile ? 1 : 0;
                $response->is_crawler = $response->is_crawler ? 1 : 0;
                $objectManager = \Magento\Framework\App\ObjectManager::getInstance();
                $resource = $objectManager->get('Magento\Framework\App\ResourceConnection');
                $connection = $resource->getConnection();
                $sql = "INSERT INTO ipqualityscore_proxy () VALUES(?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";

                $query = $connection->prepare($sql);
                $query->bindParam(1, $response->fruad_score);
                $query->bindParam(2, $response->proxy);
                $query->bindParam(3, $response->ISP);
                $query->bindParam(4, $response->organization);
                $query->bindParam(5, $response->ASN);
                $query->bindParam(6, $response->host);
                $query->bindParam(7, $response->country_code);
                $query->bindParam(8, $response->city);
                $query->bindParam(9, $response->region);
                $query->bindParam(10, $response->is_crawler);
                $query->bindParam(11, $response->latitude);
                $query->bindParam(12, $response->longitude);
                $query->bindParam(13, $response->timezone);
                $query->bindParam(14, $response->vpn);
                $query->bindParam(15, $response->tor);
                $query->bindParam(16, $response->recent_abuse);
                $query->bindParam(17, $response->bot_status);
                $query->bindParam(18, $response->mobile);
                $query->bindParam(19, $response->operating_system);
                $query->bindParam(20, $response->browser);
                $query->bindParam(21, $response->device_model);
                $query->bindParam(22, $response->device_brand);
                $query->bindParam(23, $response->valid_billing_address);
                $query->bindParam(24, $response->valid_shipping_address);
                $query->bindParam(25, $response->valid_billing_email);
                $query->bindParam(26, $response->valid_shipping_email);
                $query->bindParam(27, $response->risky_billing_phone);
                $query->bindParam(28, $response->risky_shipping_phone);
                $query->bindParam(29, $response->fraudulent_behaviour);
                $query->bindParam(30, $response->bin_country);
                $query->bindParam(31, $response->risky_username);
                $query->bindParam(32, $response->valid_billing_phone);
                $query->bindParam(33, $response->valid_shipping_phone);
                $query->bindParam(34, $response->request_id);
                $query->execute();
                $connection->query($sql);

                $this->logger->info("Proxy response: " . json_encode($response));
                $emailResponse = $client->validateEmail($email);
                $this->logger->info("Email response: " . json_encode($emailResponse));
                $emailValid = $emailResponse->valid ? 1 : 0;
                $emailDisposable = $emailResponse->disposable ? 1 : 0;
                $emailTimedOut = $emailResponse->timed_out ? 1 : 0;
                $emailSuspect = $emailResponse->suspect ? 1 : 0;
                $emailSmptScore = $emailResponse->smtp_score ? 1 : 0;
                $emailOverAllScore = $emailResponse->overall_score ? 1 : 0;
                $emailGeneric = $emailResponse->generic ? 1 : 0;
                $emailCommon = $emailResponse->common ? 1 : 0;
                $emailDnsValid = $emailResponse->dns_valid ? 1 : 0;
                $emailHoneypot = $emailResponse->honeypot ? 1 : 0;
                $emailRecentAbuse = $emailResponse->recent_abuse ? 1 : 0;
                $emailFrequentComplainer = $emailResponse->frequent_complainer ? 1 : 0;
                $emailCatchAll = $emailResponse->catch_all ? 1 : 0;
                $emailLeaked = $emailResponse->leaked ? 1 : 0;


                if (!$emailResponse->cached) {
                    $this->logger->info("SAVING EMAIL");
                    $sql = "INSERT INTO ipqualityscore_email () VALUES(?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
                    $this->logger->info("Email SQL: " . $sql);
                    $objectManager = \Magento\Framework\App\ObjectManager::getInstance();
                    $resource = $objectManager->get('Magento\Framework\App\ResourceConnection');
                    $connection = $resource->getConnection();
                    $query = $connection->prepare($sql);
                    $query->bindParam(1,$email);
                    $query->bindParam(2,$emailValid);
                    $query->bindParam(3,$emailDisposable);
                    $query->bindParam(4,$emailTimedOut);
                    $query->bindParam(5,$emailResponse->deliverability);
                    $query->bindParam(6,$emailSuspect);
                    $query->bindParam(7,$emailSmptScore);
                    $query->bindParam(8,$emailOverAllScore);
                    $query->bindParam(9,$emailResponse->first_name);
                    $query->bindParam(10,$emailGeneric);
                    $query->bindParam(11,$emailCommon);
                    $query->bindParam(12,$emailDnsValid);
                    $query->bindParam(13,$emailHoneypot);
                    $query->bindParam(14,$emailRecentAbuse);
                    $query->bindParam(15,$emailFrequentComplainer);
                    $query->bindParam(16,$emailResponse->suggested_domain);
                    $query->bindParam(17,$emailCatchAll);
                    $query->bindParam(18,$emailResponse->spam_trap_score);
                    $query->bindParam(19,$emailResponse->request_id);
                    $query->bindParam(20,$emailLeaked);
                    $query->bindParam(21,0);
                    $query->execute();
                }
                $objectManager = \Magento\Framework\App\ObjectManager::getInstance();
                $resource = $objectManager->get('Magento\Framework\App\ResourceConnection');
                $connection = $resource->getConnection();
                $sql = "SELECT * FROM ipqualityscore_devices WHERE order_id=?";
                $query = $connection->prepare($sql);
                $query->bindParam(1, $orderId);
                $query->execute();
                $device = $query->fetchAll(\PDO::FETCH_CLASS);

                $proxyScore = $response->fraud_score;
                $emailScore =  $emailResponse->overall_score;
                $validPhone = $response->transaction_details->valid_billing_phone ? 1 : 0;
                $validAddress = $response->transaction_details->valid_billing_address ? 1 : 0;
                if ($device) {
                    $deviceScore = $device[0]->fraud_chance;
                } else {
                    $deviceScore = 0;
                }
                $requestId = $response->request_id;


                $objectManager = \Magento\Framework\App\ObjectManager::getInstance();
                $resource = $objectManager->get('Magento\Framework\App\ResourceConnection');
                $connection = $resource->getConnection();
                $sql = "INSERT INTO ipqualityscore_orders  VALUES(?,?,?,?,?,?,?,?,?)";
                $query = $connection->prepare($sql);
                $query->bindParam(1,$orderId);
                $query->bindParam(2,$orderId);
                $query->bindParam(3,$proxyScore);
                $query->bindParam(4,$emailScore);
                $query->bindParam(5,$deviceScore);
                $query->bindParam(6,$validPhone);
                $query->bindParam(7,$validAddress);
                $query->bindParam(8,0);
                $query->bindParam(9,$requestId);
                $query->execute();
            }
        } catch (\Exception $e) {
            $this->logger->info($e->getMessage());
            echo $e->getMessage();
            die();
        }
    }
}
